@@ -11,12 +11,12 @@ pets = [
 ]
 
 
-class PetInSchema(Schema):
+class PetIn(Schema):
     name = String(required=True, validate=Length(0, 10))
     category = String(required=True, validate=OneOf(['dog', 'cat']))
 
 
-class PetOutSchema(Schema):
+class PetOut(Schema):
     id = Integer()
     name = String()
     category = String()
@@ -28,7 +28,7 @@ def say_hello():
 
 
 @app.get('/pets/<int:pet_id>')
-@app.output(PetOutSchema)
+@app.output(PetOut)
 def get_pet(pet_id):
     if pet_id > len(pets) - 1 or pets[pet_id].get('deleted'):
         abort(404)
@@ -36,14 +36,14 @@ def get_pet(pet_id):
 
 
 @app.get('/pets')
-@app.output(PetOutSchema(many=True))
+@app.output(PetOut(many=True))
 def get_pets():
     return pets
 
 
 @app.post('/pets')
-@app.input(PetInSchema)
-@app.output(PetOutSchema, 201)
+@app.input(PetIn)
+@app.output(PetOut, status_code=201)
 def create_pet(data):
     pet_id = len(pets)
     data['id'] = pet_id
@@ -52,8 +52,8 @@ def create_pet(data):
 
 
 @app.patch('/pets/<int:pet_id>')
-@app.input(PetInSchema(partial=True))
-@app.output(PetOutSchema)
+@app.input(PetIn(partial=True))
+@app.output(PetOut)
 def update_pet(pet_id, data):
     if pet_id > len(pets) - 1:
         abort(404)
@@ -63,7 +63,7 @@ def update_pet(pet_id, data):
 
 
 @app.delete('/pets/<int:pet_id>')
-@app.output({}, 204)
+@app.output({}, status_code=204)
 def delete_pet(pet_id):
     if pet_id > len(pets) - 1:
         abort(404)
