@@ -20,12 +20,12 @@ pets = [
 ]
 
 
-class PetInSchema(Schema):
+class PetIn(Schema):
     name = String(required=True, validate=Length(0, 10))
     category = String(required=True, validate=OneOf(['dog', 'cat']))
 
 
-class PetOutSchema(Schema):
+class PetOut(Schema):
     id = Integer()
     name = String()
     category = String()
@@ -37,7 +37,7 @@ def say_hello():
 
 
 @pet_bp.get('/pets/<int:pet_id>')
-@pet_bp.output(PetOutSchema)
+@pet_bp.output(PetOut)
 def get_pet(pet_id):
     if pet_id > len(pets) - 1 or pets[pet_id].get('deleted'):
         abort(404)
@@ -45,14 +45,14 @@ def get_pet(pet_id):
 
 
 @pet_bp.get('/pets')
-@pet_bp.output(PetOutSchema(many=True))
+@pet_bp.output(PetOut(many=True))
 def get_pets():
     return pets
 
 
 @pet_bp.post('/pets')
-@pet_bp.input(PetInSchema)
-@pet_bp.output(PetOutSchema, 201)
+@pet_bp.input(PetIn)
+@pet_bp.output(PetOut, status_code=201)
 def create_pet(data):
     pet_id = len(pets)
     data['id'] = pet_id
@@ -61,8 +61,8 @@ def create_pet(data):
 
 
 @pet_bp.patch('/pets/<int:pet_id>')
-@pet_bp.input(PetInSchema(partial=True))
-@pet_bp.output(PetOutSchema)
+@pet_bp.input(PetIn(partial=True))
+@pet_bp.output(PetOut)
 def update_pet(pet_id, data):
     if pet_id > len(pets) - 1:
         abort(404)
@@ -72,7 +72,7 @@ def update_pet(pet_id, data):
 
 
 @pet_bp.delete('/pets/<int:pet_id>')
-@pet_bp.output({}, 204)
+@pet_bp.output({}, status_code=204)
 def delete_pet(pet_id):
     if pet_id > len(pets) - 1:
         abort(404)
