@@ -1,7 +1,7 @@
 from apiflask import APIFlask, Schema, abort
 from apiflask.fields import Integer, String
 from apiflask.validators import Length, OneOf
-from flask.views import MethodView
+from apiflask.views import MethodView
 
 app = APIFlask(__name__)
 
@@ -12,36 +12,34 @@ pets = [
 ]
 
 
-class PetInSchema(Schema):
+class PetIn(Schema):
     name = String(required=True, validate=Length(0, 10))
     category = String(required=True, validate=OneOf(['dog', 'cat']))
 
 
-class PetOutSchema(Schema):
+class PetOut(Schema):
     id = Integer()
     name = String()
     category = String()
 
 
-@app.route('/')
 class Hello(MethodView):
 
     def get(self):
         return {'message': 'Hello!'}
 
 
-@app.route('/pets/<int:pet_id>')
 class Pet(MethodView):
 
-    @app.output(PetOutSchema)
+    @app.output(PetOut)
     def get(self, pet_id):
         """Get a pet"""
         if pet_id > len(pets) - 1 or pets[pet_id].get('deleted'):
             abort(404)
         return pets[pet_id]
 
-    @app.input(PetInSchema(partial=True))
-    @app.output(PetOutSchema)
+    @app.input(PetIn(partial=True))
+    @app.output(PetOut)
     def patch(self, pet_id, data):
         """Update a pet"""
         if pet_id > len(pets) - 1:
@@ -50,7 +48,7 @@ class Pet(MethodView):
             pets[pet_id][attr] = value
         return pets[pet_id]
 
-    @app.output({}, 204)
+    @app.output({}, status_code=204)
     def delete(self, pet_id):
         """Delete a pet"""
         if pet_id > len(pets) - 1:
@@ -60,19 +58,23 @@ class Pet(MethodView):
         return ''
 
 
-@app.route('/pets')
 class Pets(MethodView):
 
-    @app.output(PetOutSchema(many=True))
+    @app.output(PetOut(many=True))
     def get(self):
         """Get all pets"""
         return pets
 
-    @app.input(PetInSchema)
-    @app.output(PetOutSchema, 201)
+    @app.input(PetIn)
+    @app.output(PetOut, status_code=201)
     def post(self, data):
         """Create a pet"""
         pet_id = len(pets)
         data['id'] = pet_id
         pets.append(data)
         return pets[pet_id]
+
+
+app.add_url_rule('/', view_func=Hello.as_view('hello'))
+app.add_url_rule('/pets/<int:pet_id>', view_func=Pet.as_view('pet'))
+app.add_url_rule('/pets', view_func=Pets.as_view('pets'))
