@@ -31,12 +31,12 @@ def init_database():
     db.session.commit()
 
 
-class PetInSchema(Schema):
+class PetIn(Schema):
     name = String(required=True, validate=Length(0, 10))
     category = String(required=True, validate=OneOf(['dog', 'cat']))
 
 
-class PetOutSchema(Schema):
+class PetOut(Schema):
     id = Integer()
     name = String()
     category = String()
@@ -48,20 +48,20 @@ def say_hello():
 
 
 @app.get('/pets/<int:pet_id>')
-@app.output(PetOutSchema)
+@app.output(PetOut)
 def get_pet(pet_id):
     return PetModel.query.get_or_404(pet_id)
 
 
 @app.get('/pets')
-@app.output(PetOutSchema(many=True))
+@app.output(PetOut(many=True))
 def get_pets():
     return PetModel.query.all()
 
 
 @app.post('/pets')
-@app.input(PetInSchema)
-@app.output(PetOutSchema, 201)
+@app.input(PetIn)
+@app.output(PetOut, status_code=201)
 def create_pet(data):
     pet = PetModel(**data)
     db.session.add(pet)
@@ -70,8 +70,8 @@ def create_pet(data):
 
 
 @app.patch('/pets/<int:pet_id>')
-@app.input(PetInSchema(partial=True))
-@app.output(PetOutSchema)
+@app.input(PetIn(partial=True))
+@app.output(PetOut)
 def update_pet(pet_id, data):
     pet = PetModel.query.get_or_404(pet_id)
     for attr, value in data.items():
@@ -81,7 +81,7 @@ def update_pet(pet_id, data):
 
 
 @app.delete('/pets/<int:pet_id>')
-@app.output({}, 204)
+@app.output({}, status_code=204)
 def delete_pet(pet_id):
     pet = PetModel.query.get_or_404(pet_id)
     db.session.delete(pet)
