@@ -10,13 +10,21 @@ if sys.platform == 'win32' and (3, 8, 0) <= sys.version_info < (3, 9, 0):  # pra
     asyncio.set_event_loop_policy(asyncio.WindowsSelectorEventLoopPolicy())  # pragma: no cover
 
 from apispec import APISpec
+from apispec import BasePlugin
 from apispec.ext.marshmallow import MarshmallowPlugin
 from flask import Blueprint
 from flask import Flask
+from flask import has_request_context
 from flask import jsonify
 from flask import render_template_string
+from flask import request
 from flask.config import ConfigAttribute
-from flask.globals import _request_ctx_stack
+try:
+    from flask.globals import request_ctx  # type: ignore
+except ImportError:  # pragma: no cover
+    from flask.globals import _request_ctx_stack
+    request_ctx = None  # type: ignore
+from flask.wrappers import Response
 
 with warnings.catch_warnings():
     warnings.simplefilter('ignore')
@@ -43,6 +51,7 @@ from .types import TagsType
 from .types import OpenAPISchemaType
 from .openapi import add_response
 from .openapi import add_response_with_schema
+from .openapi import default_bypassed_endpoints
 from .openapi import default_response
 from .openapi import get_tag
 from .openapi import get_operation_tags
@@ -51,7 +60,7 @@ from .openapi import get_auth_name
 from .openapi import get_argument
 from .openapi import get_security_and_security_schemes
 from .ui_templates import redoc_template
-from .ui_templates import swagger_ui_template
+from .ui_templates import ui_templates
 from .ui_templates import swagger_ui_oauth2_redirect_template
 from .scaffold import APIScaffold
 
@@ -264,13 +273,15 @@ class APIFlask(APIScaffold, Flask):
         import_name: str,
         title: str = 'APIFlask',
         version: str = '0.1.0',
-        spec_path: str = '/openapi.json',
-        docs_path: str = '/docs',
-        docs_oauth2_redirect_path: str = '/docs/oauth2-redirect',
-        redoc_path: str = '/redoc',
+        spec_path: t.Optional[str] = '/openapi.json',
+        docs_path: t.Optional[str] = '/docs',
+        docs_oauth2_redirect_path: t.Optional[str] = '/docs/oauth2-redirect',
+        docs_ui: str = 'swagger-ui',
+        redoc_path: t.Optional[str] = '/redoc',
         openapi_blueprint_url_prefix: t.Optional[str] = None,
         json_errors: bool = True,
         enable_openapi: bool = True,
+        spec_plugins: t.Optional[t.List[BasePlugin]] = None,
         static_url_path: t.Optional[str] = None,
         static_folder: str = 'static',
         static_host: t.Optional[str] = None,
@@ -293,20 +304,34 @@ class APIFlask(APIScaffold, Flask):
             spec_path: The path to OpenAPI Spec documentation. It
                 defaults to `/openapi.json`, if the path ends with `.yaml`
                 or `.yml`, the YAML format of the OAS will be returned.
-            docs_path: The path to Swagger UI documentation, defaults to `/docs`.
+            docs_path: The path to API UI documentation, defaults to `/docs`.
+            docs_ui: The UI of API documentation, one of `swagger-ui` (default), `redoc`,
+                `elements`, `rapidoc`, and `rapipdf`.
             docs_oauth2_redirect_path: The path to Swagger UI OAuth redirect.
-            redoc_path: The path to Redoc documentation, defaults to `/redoc`.
+            redoc_path: Deprecated since 1.1, set `APIFlask(docs_ui='redoc')` to use Redoc.
+                The path to Redoc documentation, defaults to `/redoc`.
             openapi_blueprint_url_prefix: The url prefix of the OpenAPI blueprint. This
                 prefix will append before all the OpenAPI-related paths (`sepc_path`,
                 `docs_path`, etc.), defaults to `None`.
             json_errors: If `True`, APIFlask will return a JSON response for HTTP errors.
             enable_openapi: If `False`, will disable OpenAPI spec and API docs views.
+            spec_plugins: List of apispec-compatible plugins (subclasses of `apispec.BasePlugin`),
+                defaults to `None`. The `MarshmallowPlugin` for apispec is already included
+                by default, so it doesn't need to be provided here.
 
         Other keyword arguments are directly passed to `flask.Flask`.
 
+        *Version changed: 1.2.0*
+
+        - Add `spec_plugins` parameter.
+
+        *Version changed: 1.1.0*
+
+        - Add `docs_ui` parameter.
+
         *Version changed: 0.7.0*
 
-        - Add `openapi_blueprint_url_prefix` argument.
+        - Add `openapi_blueprint_url_prefix` parameter.
         """
         super().__init__(
             import_name,
@@ -327,6 +352,7 @@ class APIFlask(APIScaffold, Flask):
         self.title = title
         self.version = version
         self.spec_path = spec_path
+        self.docs_ui = docs_ui
         self.docs_path = docs_path
         self.redoc_path = redoc_path
         self.docs_oauth2_redirect_path = docs_oauth2_redirect_path
@@ -338,6 +364,7 @@ class APIFlask(APIScaffold, Flask):
         self.error_callback: ErrorCallbackType = self._error_handler
         self.schema_name_resolver = self._schema_name_resolver
 
+        self.spec_plugins: t.List[BasePlugin] = spec_plugins or []
         self._spec: t.Optional[t.Union[dict, str]] = None
         self._auth_blueprints: t.Dict[str, t.Dict[str, t.Any]] = {}
 
@@ -386,8 +413,8 @@ class APIFlask(APIScaffold, Flask):
 
         ```python
         @app.get('/pets/<name>/<int:pet_id>/<age>')  # -> name, pet_id, age
-        @app.input(QuerySchema)  # -> query
-        @app.output(PetSchema)  # -> pet
+        @app.input(Query)  # -> query
+        @app.output(Pet)  # -> pet
         def get_pet(name, pet_id, age, query, pet):
             pass
         ```
@@ -396,27 +423,41 @@ class APIFlask(APIScaffold, Flask):
 
         *Version added: 0.2.0*
         """
-        req = _request_ctx_stack.top.request
+        req = request_ctx.request if request_ctx else _request_ctx_stack.top.request  # type: ignore
         if req.routing_exception is not None:
             self.raise_routing_exception(req)
         rule = req.url_rule
         # if we provide automatic options for this URL and the
         # request came with the OPTIONS method, reply automatically
         if (  # pragma: no cover
-            getattr(rule, "provide_automatic_options", False)
-            and req.method == "OPTIONS"
+            getattr(rule, 'provide_automatic_options', False)
+            and req.method == 'OPTIONS'
         ):
             return self.make_default_options_response()  # pragma: no cover
         # otherwise dispatch to the handler for that endpoint
         view_function = self.view_functions[rule.endpoint]
         if hasattr(self, 'ensure_sync'):  # pragma: no cover
             view_function = self.ensure_sync(view_function)
-        if rule.endpoint == 'static':
+        if rule.endpoint == 'static' or hasattr(view_function, '_only_kwargs'):
             # app static route only accepts keyword arguments, see flask#3762
+            # view classes created by Flask only accept keyword arguments
             return view_function(**req.view_args)  # type: ignore
         else:
             return view_function(*req.view_args.values())  # type: ignore
 
+    # TODO: remove this function when we dropped the Flask 1.x support
+    # the list return values are supported in Flask 2.2
+    def make_response(self, rv) -> Response:
+        """Patch the make_response form Flask to allow returning list as JSON.
+
+        *Version added: 1.1.0*
+        """
+        if isinstance(rv, list):
+            rv = jsonify(rv)
+        elif isinstance(rv, tuple) and isinstance(rv[0], list):
+            rv = (jsonify(rv[0]), *rv[1:])
+        return super().make_response(rv)
+
     @staticmethod
     def _error_handler(
         error: HTTPError
@@ -476,7 +517,7 @@ class APIFlask(APIScaffold, Flask):
         so you can get error information via it's attributes:
 
         - status_code: If the error is triggered by a validation error, the value will be
-          400 (default) or the value you passed in config `VALIDATION_ERROR_STATUS_CODE`.
+          422 (default) or the value you passed in config `VALIDATION_ERROR_STATUS_CODE`.
           If the error is triggered by [`HTTPError`][apiflask.exceptions.HTTPError]
           or [`abort`][apiflask.exceptions.abort], it will be the status code
           you passed. Otherwise, it will be the status code set by Werkzueg when
@@ -537,7 +578,11 @@ class APIFlask(APIScaffold, Flask):
         """Register a blueprint for OpenAPI support.
 
         The name of the blueprint is "openapi". This blueprint will hold the view
-        functions for spec file, Swagger UI and Redoc.
+        functions for spec file and API docs.
+
+        *Version changed: 1.1.0*
+
+        - Deprecate the redoc view at /redoc path.
 
         *Version changed: 0.7.0*
 
@@ -551,7 +596,7 @@ class APIFlask(APIScaffold, Flask):
 
         if self.spec_path:
             @bp.route(self.spec_path)
-            def spec() -> ResponseReturnValueType:
+            def spec():
                 if self.config['SPEC_FORMAT'] == 'json':
                     response = jsonify(self._get_spec('json'))
                     response.mimetype = self.config['JSON_SPEC_MIMETYPE']
@@ -560,23 +605,38 @@ class APIFlask(APIScaffold, Flask):
                     {'Content-Type': self.config['YAML_SPEC_MIMETYPE']}
 
         if self.docs_path:
+            if self.docs_ui not in ui_templates:
+                valid_values = list(ui_templates.keys())
+                raise ValueError(
+                    f'Invalid docs_ui value, expected one of {valid_values!r}, '
+                    f'got {self.docs_ui!r}.'
+                )
+
             @bp.route(self.docs_path)
-            def swagger_ui() -> str:
+            def docs():
                 return render_template_string(
-                    swagger_ui_template,
+                    ui_templates[self.docs_ui],
                     title=self.title,
                     version=self.version,
                     oauth2_redirect_path=self.docs_oauth2_redirect_path
                 )
 
-            if self.docs_oauth2_redirect_path:
-                @bp.route(self.docs_oauth2_redirect_path)
-                def swagger_ui_oauth_redirect() -> str:
-                    return render_template_string(swagger_ui_oauth2_redirect_template)
+            if self.docs_ui == 'swagger-ui':
+                if self.docs_oauth2_redirect_path:
+                    @bp.route(self.docs_oauth2_redirect_path)
+                    def swagger_ui_oauth_redirect() -> str:
+                        return render_template_string(swagger_ui_oauth2_redirect_template)
 
         if self.redoc_path:
             @bp.route(self.redoc_path)
-            def redoc() -> str:
+            def redoc():
+                warnings.warn(
+                    'The `/redoc` path and `redoc_path` parameter is deprecated '
+                    'and will be removed in 2.0, Set `APIFlask(docs_ui="redoc")` '
+                    'to use Redoc and then visit "/docs" instead.',
+                    UserWarning,
+                    stacklevel=2,
+                )
                 return render_template_string(
                     redoc_template,
                     title=self.title,
@@ -786,6 +846,10 @@ class APIFlask(APIScaffold, Flask):
     def _generate_spec(self) -> APISpec:
         """Generate the spec, return an instance of `apispec.APISpec`.
 
+        *Version changed: 1.2.1*
+
+        - Set default `servers` value.
+
         *Version changed: 0.10.0*
 
         - Add support for `operationId`.
@@ -802,17 +866,23 @@ class APIFlask(APIScaffold, Flask):
         kwargs: dict = {}
         if self.servers:
             kwargs['servers'] = self.servers
+        else:
+            if self.config['AUTO_SERVERS'] and has_request_context():
+                kwargs['servers'] = [{'url': request.url_root}]
         if self.external_docs:
             kwargs['externalDocs'] = self.external_docs
 
         ma_plugin: MarshmallowPlugin = MarshmallowPlugin(
-            schema_name_resolver=self.schema_name_resolver
+            schema_name_resolver=self.schema_name_resolver  # type: ignore
         )
+
+        spec_plugins: t.List[BasePlugin] = [ma_plugin, *self.spec_plugins]
+
         spec: APISpec = APISpec(
             title=self.title,
             version=self.version,
             openapi_version=self.config['OPENAPI_VERSION'],
-            plugins=[ma_plugin],
+            plugins=spec_plugins,
             info=self._make_info(),
             tags=self._make_tags(),
             **kwargs
@@ -828,13 +898,13 @@ class APIFlask(APIScaffold, Flask):
                 'string', 'url'
             )
 
+        auth_names, auth_schemes = self._collect_security_info()
+        security, security_schemes = get_security_and_security_schemes(
+            auth_names, auth_schemes
+        )
+
         if self.config['SECURITY_SCHEMES'] is not None:
-            security_schemes = self.config['SECURITY_SCHEMES']
-        else:
-            auth_names, auth_schemes = self._collect_security_info()
-            security, security_schemes = get_security_and_security_schemes(
-                auth_names, auth_schemes
-            )
+            security_schemes.update(self.config['SECURITY_SCHEMES'])
 
         for name, scheme in security_schemes.items():
             spec.components.security_scheme(name, scheme)
@@ -848,8 +918,7 @@ class APIFlask(APIScaffold, Flask):
             operations: t.Dict[str, t.Any] = {}
             view_func: ViewFuncType = self.view_functions[rule.endpoint]  # type: ignore
             # skip endpoints from openapi blueprint and the built-in static endpoint
-            if rule.endpoint.startswith('openapi') or \
-               rule.endpoint.startswith('static'):
+            if rule.endpoint in default_bypassed_endpoints:
                 continue
             blueprint_name: t.Optional[str] = None  # type: ignore
             if '.' in rule.endpoint:
@@ -859,7 +928,8 @@ class APIFlask(APIScaffold, Flask):
                     # just a normal view with dots in its endpoint, reset blueprint_name
                     blueprint_name = None
                 else:
-                    if not hasattr(blueprint, 'enable_openapi') or \
+                    if rule.endpoint == (f'{blueprint_name}.static') or \
+                       not hasattr(blueprint, 'enable_openapi') or \
                        not blueprint.enable_openapi:  # type: ignore
                         continue
             # add a default 200 response for bare views
@@ -987,7 +1057,7 @@ class APIFlask(APIScaffold, Flask):
                         data_key: str = self.config['BASE_RESPONSE_DATA_KEY']
                         if data_key not in base_schema_spec['properties']:
                             raise RuntimeError(
-                                f'The data key "{data_key}" is not found in'
+                                f'The data key {data_key!r} is not found in'
                                 ' the base response schema spec.'
                             )
                         base_schema_spec['properties'][data_key] = schema
@@ -1127,7 +1197,13 @@ class APIFlask(APIScaffold, Flask):
 
             # parameters
             path_arguments: t.Iterable = re.findall(r'<(([^<:]+:)?([^>]+))>', rule.rule)
-            if path_arguments:
+            if (
+                path_arguments
+                and not (
+                    hasattr(view_func, '_spec')
+                    and view_func._spec.get('omit_default_path_parameters', False)
+                )
+            ):
                 arguments: t.List[t.Dict[str, str]] = []
                 for _, argument_type, argument_name in path_arguments:
                     argument = get_argument(argument_type, argument_name)
