@@ -35,6 +35,7 @@ from marshmallow.fields import TimeDelta as TimeDelta
 from marshmallow.fields import Tuple as Tuple
 from marshmallow.fields import URL as URL
 from marshmallow.fields import UUID as UUID
+from marshmallow.fields import Enum as Enum
 from webargs.fields import DelimitedList as DelimitedList
 from webargs.fields import DelimitedTuple as DelimitedTuple
 
@@ -51,12 +52,12 @@ class File(Field):
     from apiflask.fields import File
 
 
-    class ImageSchema(Schema):
+    class Image(Schema):
         image = File()
 
 
     @app.post('/images')
-    @app.input(ImageSchema, location='files')
+    @app.input(Image, location='files')
     def upload_image(data):
         f = data['image']
         # use `secure_filename` to clean the filename, notice it will only keep ascii characters
@@ -65,10 +66,8 @@ class File(Field):
 
         return {'message': f'file {filename} saved.'}
     ```
-    The file object is an instance of `werkzeug.datastructures.FileStorage`, see more details
-    [in the docs][_docs].
-
-    _docs: https://werkzeug.palletsprojects.com/datastructures/#werkzeug.datastructures.FileStorage
+    The file object is an instance of `werkzeug.datastructures.FileStorage`, see more details in the
+    [docs](https://werkzeug.palletsprojects.com/datastructures/#werkzeug.datastructures.FileStorage).  # noqa: B950, E501
 
     Use `form_and_files` location if you want to put both files
     and other normal fields in one schema.
@@ -80,12 +79,12 @@ class File(Field):
     from apiflask.fields import String, File
 
 
-    class ProfileInSchema(Schema):
+    class ProfileIn(Schema):
         name = String()
         avatar = File()
 
     @app.post('/profiles')
-    @app.input(ProfileInSchema, location='form_and_files')
+    @app.input(ProfileIn, location='form_and_files')
     def create_profile(data):
         avatar_file = data['avatar']
         name = data['name']
