@@ -15,6 +15,15 @@ if t.TYPE_CHECKING:  # pragma: no cover
     from .blueprint import APIBlueprint
 
 
+default_bypassed_endpoints: t.List[str] = [
+    'static',
+    'openapi.spec',
+    'openapi.docs',
+    'openapi.redoc',
+    'openapi.swagger_ui_oauth_redirect',
+    '_debug_toolbar.static',  # Flask-DebugToolbar
+]
+
 default_response = {
     'schema': {},
     'status_code': 200,
@@ -66,7 +75,7 @@ def get_auth_name(
     if isinstance(auth, HTTPBasicAuth):
         name = 'BasicAuth'
     elif isinstance(auth, HTTPTokenAuth):
-        if auth.scheme == 'Bearer' and auth.header is None:
+        if auth.scheme.lower() == 'bearer' and auth.header is None:
             name = 'BearerAuth'
         else:
             name = 'ApiKeyAuth'
@@ -86,10 +95,10 @@ def get_security_scheme(auth: HTTPAuthType) -> t.Dict[str, t.Any]:
     """Get security scheme from auth object."""
     security_scheme: t.Dict[str, t.Any]
     if isinstance(auth, HTTPTokenAuth):
-        if auth.scheme == 'Bearer' and auth.header is None:
+        if auth.scheme.lower() == 'bearer' and auth.header is None:
             security_scheme = {
                 'type': 'http',
-                'scheme': 'Bearer',
+                'scheme': 'bearer',
             }
         else:
             security_scheme = {
@@ -100,7 +109,7 @@ def get_security_scheme(auth: HTTPAuthType) -> t.Dict[str, t.Any]:
     else:
         security_scheme = {
             'type': 'http',
-            'scheme': 'Basic',
+            'scheme': 'basic',
         }
     return security_scheme
 
@@ -112,7 +121,7 @@ def get_security_and_security_schemes(
     """Make security and security schemes from given auth names and schemes."""
     security: t.Dict[HTTPAuthType, str] = {}
     security_schemes: t.Dict[str, t.Dict[str, str]] = {}
-    for name, auth in zip(auth_names, auth_schemes):
+    for name, auth in zip(auth_names, auth_schemes):  # noqa: B905
         security[auth] = name
         security_schemes[name] = get_security_scheme(auth)
         if hasattr(auth, 'description') and auth.description is not None:
