@@ -3,10 +3,10 @@ import warnings
 from collections.abc import Mapping as ABCMapping
 from functools import wraps
 
+import flask
 from flask import current_app
 from flask import jsonify
 from flask import Response
-from flask.views import MethodViewType
 from marshmallow import ValidationError as MarshmallowValidationError
 from webargs.flaskparser import FlaskParser as BaseFlaskParser
 from webargs.multidictproxy import MultiDictProxy
@@ -22,9 +22,9 @@ from .types import OpenAPISchemaType
 from .types import RequestType
 from .types import ResponseReturnValueType
 from .types import SchemaType
+from .views import MethodView
 
 BODY_LOCATIONS = ['json', 'files', 'form', 'form_and_files', 'json_or_form']
-SUPPORTED_LOCATIONS = BODY_LOCATIONS + ['query', 'headers', 'cookies', 'querystring']
 
 
 class FlaskParser(BaseFlaskParser):
@@ -78,6 +78,18 @@ def _annotate(f: t.Any, **kwargs: t.Any) -> None:
         f._spec[key] = value
 
 
+def _ensure_sync(f):
+    if flask.__version__ < '2.' or hasattr(f, '_sync_ensured'):
+        return f
+
+    @wraps(f)
+    def wrapper(*args, **kwargs):
+        return current_app.ensure_sync(f)(*args, **kwargs)
+
+    wrapper._sync_ensured = True
+    return wrapper
+
+
 def _generate_schema_from_mapping(
     schema: DictSchemaType,
     schema_name: t.Optional[str]
@@ -101,7 +113,7 @@ class APIScaffold:
             raise RuntimeError('Use the "route" decorator to use the "methods" argument.')
 
         def decorator(f):
-            if isinstance(f, MethodViewType):
+            if isinstance(f, type(MethodView)):
                 raise RuntimeError(
                     'The route shortcuts cannot be used with "MethodView" classes, '
                     'use the "route" decorator instead.'
@@ -144,7 +156,7 @@ class APIScaffold:
         Examples:
 
         ```python
-        from apiflask import APIFlask, HTTPTokenAuth, auth_required
+        from apiflask import APIFlask, HTTPTokenAuth
 
         app = APIFlask(__name__)
         auth = HTTPTokenAuth()
@@ -192,6 +204,7 @@ class APIScaffold:
             _roles = roles
 
         def decorator(f):
+            f = _ensure_sync(f)
             _annotate(f, auth=auth, roles=_roles or [])
             return auth.login_required(role=_roles, optional=optional)(f)
         return decorator
@@ -217,12 +230,12 @@ class APIScaffold:
         Examples:
 
         ```python
-        from apiflask import APIFlask, input
+        from apiflask import APIFlask
 
         app = APIFlask(__name__)
 
         @app.get('/')
-        @app.input(PetInSchema)
+        @app.input(PetIn)
         def hello(parsed_and_validated_input_data):
             print(parsed_and_validated_input_data)
             return 'Hello'!
@@ -275,6 +288,7 @@ class APIScaffold:
             schema = schema()
 
         def decorator(f):
+            f = _ensure_sync(f)
             is_body_location = location in BODY_LOCATIONS
             if is_body_location and hasattr(f, '_spec') and 'body' in f._spec:
                 raise RuntimeError(
@@ -282,12 +296,6 @@ class APIScaffold:
                     'body location (one of "json", "form", "files", "form_and_files", '
                     'and "json_or_form").'
                 )
-            if location not in SUPPORTED_LOCATIONS:
-                raise ValueError(
-                    'Unknown input location. The supported locations are: "json", "files",'
-                    ' "form", "cookies", "headers", "query" (same as "querystring"), and '
-                    f'"form_and_files". Got "{location}" instead.'
-                )
             if location == 'json':
                 _annotate(f, body=schema, body_example=example, body_examples=examples)
             elif location == 'form':
@@ -309,6 +317,8 @@ class APIScaffold:
             else:
                 if not hasattr(f, '_spec') or f._spec.get('args') is None:
                     _annotate(f, args=[])
+                if location == 'path':
+                    _annotate(f, omit_default_path_parameters=True)
                 # TODO: Support set example for request parameters
                 f._spec['args'].append((schema, location))
             return use_args(schema, location=location, **kwargs)(f)
@@ -340,12 +350,12 @@ class APIScaffold:
         Examples:
 
         ```python
-        from apiflask import APIFlask, output
+        from apiflask import APIFlask
 
         app = APIFlask(__name__)
 
         @app.get('/')
-        @app.output(PetOutSchema)
+        @app.output(PetOut)
         def hello():
             return the_dict_or_object_match_petout_schema
         ```
@@ -425,6 +435,7 @@ class APIScaffold:
             status_code = 204
 
         def decorator(f):
+            f = _ensure_sync(f)
             _annotate(f, response={
                 'schema': schema,
                 'status_code': status_code,
@@ -446,11 +457,24 @@ class APIScaffold:
                 base_schema: OpenAPISchemaType = current_app.config['BASE_RESPONSE_SCHEMA']
                 if base_schema is not None and status_code != 204:
                     data_key: str = current_app.config['BASE_RESPONSE_DATA_KEY']
-                    if data_key not in obj:
-                        raise RuntimeError(
-                            f'The data key "{data_key}" is not found in the returned dict.'
+
+                    if isinstance(obj, dict):
+                        if data_key not in obj:
+                            raise RuntimeError(
+                                f'The data key {data_key!r} is not found in the returned dict.'
+                            )
+                        obj[data_key] = schema.dump(obj[data_key], many=many)  # type: ignore
+                    else:
+                        if not hasattr(obj, data_key):
+                            raise RuntimeError(
+                                f'The data key {data_key!r} is not found in the returned object.'
+                            )
+                        setattr(
+                            obj,
+                            data_key,
+                            schema.dump(getattr(obj, data_key), many=many)  # type: ignore
                         )
-                    obj[data_key] = schema.dump(obj[data_key], many=many)  # type: ignore
+
                     data = base_schema().dump(obj)  # type: ignore
                 else:
                     data = schema.dump(obj, many=many)  # type: ignore
@@ -458,10 +482,7 @@ class APIScaffold:
 
             @wraps(f)
             def _response(*args: t.Any, **kwargs: t.Any) -> ResponseReturnValueType:
-                if hasattr(current_app, 'ensure_sync'):  # pragma: no cover
-                    rv = current_app.ensure_sync(f)(*args, **kwargs)
-                else:  # pragma: no cover
-                    rv = f(*args, **kwargs)  # for Flask < 2.0
+                rv = f(*args, **kwargs)
                 if isinstance(rv, Response):
                     return rv
                 if not isinstance(rv, tuple):
@@ -497,7 +518,7 @@ class APIScaffold:
         Examples:
 
         ```python
-        from apiflask import APIFlask, doc
+        from apiflask import APIFlask
 
         app = APIFlask(__name__)
 
@@ -577,6 +598,7 @@ class APIScaffold:
             _tags = tags
 
         def decorator(f):
+            f = _ensure_sync(f)
             _annotate(
                 f,
                 summary=summary,
