@@ -1,9 +1,9 @@
-from flask.views import MethodView
 from openapi_spec_validator import validate_spec
 
 from apiflask import APIBlueprint
 from apiflask.security import HTTPBasicAuth
 from apiflask.security import HTTPTokenAuth
+from apiflask.views import MethodView
 
 
 def test_auth_required(app, client):
@@ -75,7 +75,7 @@ def test_auth_required(app, client):
     validate_spec(rv.json)
     assert 'BasicAuth' in rv.json['components']['securitySchemes']
     assert rv.json['components']['securitySchemes']['BasicAuth'] == {
-        'scheme': 'Basic',
+        'scheme': 'basic',
         'type': 'http'
     }
 
@@ -152,7 +152,7 @@ def test_auth_required_with_methodview(app, client):
     validate_spec(rv.json)
     assert 'BasicAuth' in rv.json['components']['securitySchemes']
     assert rv.json['components']['securitySchemes']['BasicAuth'] == {
-        'scheme': 'Basic',
+        'scheme': 'basic',
         'type': 'http'
     }
 
@@ -213,7 +213,7 @@ def test_auth_required_at_blueprint_before_request(app, client):
 
     assert 'BearerAuth' in rv.json['components']['securitySchemes']
     assert rv.json['components']['securitySchemes']['BearerAuth'] == {
-        'scheme': 'Bearer',
+        'scheme': 'bearer',
         'type': 'http'
     }
 
@@ -222,3 +222,20 @@ def test_auth_required_at_blueprint_before_request(app, client):
     assert 'BearerAuth' in rv.json['paths']['/baz']['get']['security'][0]
     assert 'BearerAuth' in rv.json['paths']['/baz']['post']['security'][0]
     assert 'security' not in rv.json['paths']['/eggs']['get']
+
+
+def test_lowercase_token_scheme_value(app, client):
+
+    auth = HTTPTokenAuth(scheme='bearer')
+
+    @app.route('/')
+    @app.auth_required(auth)
+    def index():
+        pass
+
+    rv = client.get('/openapi.json')
+    assert rv.status_code == 200
+    validate_spec(rv.json)
+
+    assert 'BearerAuth' in rv.json['components']['securitySchemes']
+    assert 'BearerAuth' in rv.json['paths']['/']['get']['security'][0]
